module Fragments
  # Contains a current config to request fragments properly
  # 
  # @author Sergey Gernyak
  class Config
    # Set or get a host to which request should be sent to get fragment's html structure
    attr_accessor :host

    # Contains URL prefixes
    # It should be a hash where:
    # - key is a locale in ISO2 format
    # - value is an URL prefix
    attr_accessor :uri_prefixes

    # Specifies either fragments usage is enabled or not
    attr_accessor :is_enabled

    # Provides an URI prefix for a given locale
    # @param locale [String] - A locale for which URI prefix should be returned
    # @return [String] an URI prefix
    def uri_prefix(locale)
      uri_prefixes[normalize_key(locale)] || ""
    end

    # Setter for the URI prefixes mapping hash
    # @param value [Hash] - A hash with URI prefix per locale mappings
    # @raise ArgumentError - when an invalid value has been passed
    def uri_prefixes=(value)
      raise ::ArgumentError, "Value should be a valid Hash!" unless value.is_a?(Hash)
      @uri_prefixes = Hash[value.map { |k, v| [normalize_key(k), v] }]
    end

    # Setter for enableness flag
    # @param value [Boolean] - A value of the flag
    # @raise ArgumentError - when an invalid boolean value has been passed
    def is_enabled=(value)
      raise ::ArgumentError, "Value should be a valid boolean one!" if !value.is_a?(TrueClass) && !value.is_a?(FalseClass)
      @is_enabled = value
    end

    # Provides a value which specifies are fragments enabled or not
    # By default it returns false.
    # @return [Boolean]
    def is_enabled
      !!@is_enabled
    end

    private

    def normalize_key(value)
      value.downcase.to_sym
    end
  end
end
